import Plugin from 'src/plugin-system/plugin.class';
import DomAccess from 'src/helper/dom-access.helper';

export default class QlsServicePoints extends Plugin {
    static options = {
        /**
         * URL to embed shipping points map.
         *
         * @type string
         */
        servicePointShippingMethodEndpoint: '',

        /**
         * As long as a service point has not been selected, the submit button should be disabled.
         *
         * @type boolean
         */
        disableSubmitButton: false,
    };

    init() {
        const selectServicePointButton = DomAccess.querySelector(document, '#selectServicePointButton');

        selectServicePointButton.addEventListener('click', this.openServicePointLocator.bind(this))

        const confirmFormSubmitButton = DomAccess.querySelector(document, '#confirmFormSubmit');
        const servicePointNotice = DomAccess.querySelector(document, '#servicePointNotice');

        if (this.options.disableSubmitButton) {
            confirmFormSubmitButton.disabled = true;
            servicePointNotice.style.display = 'block';
        }
    }

    openServicePointLocator() {
        const servicePointLocator = DomAccess.querySelector(document, '#servicePointLocator');

        servicePointLocator.src = this.options.servicePointShippingMethodEndpoint;
        servicePointLocator.style.display = 'block';

        addEventListener("message", this.servicePointSelected.bind(this));
    }

    servicePointSelected(event) {
        const servicePoint = event.data.servicepoint;

        this.closeServicePointLocator();

        this.submitChangeShippingForm(servicePoint);
    }

    closeServicePointLocator() {
        const servicePointLocator = DomAccess.querySelector(document, '#servicePointLocator');

        servicePointLocator.style.display = 'none';
    }

    submitChangeShippingForm(servicePoint) {
        DomAccess.querySelector(document, '#servicePointCode').value = servicePoint.servicepoint_code;
        DomAccess.querySelector(document, '#servicePointName').value = servicePoint.name;
        DomAccess.querySelector(document, '#servicePointStreetAndNumber').value = `${servicePoint.address.street} ${servicePoint.address.housenumber}`;
        DomAccess.querySelector(document, '#servicePointPostalCodeAndCity').value = `${servicePoint.address.postalcode} ${servicePoint.address.locality}`;
        DomAccess.querySelector(document, '#servicePointCountry').value = servicePoint.address.country;

        const input = DomAccess.querySelector(document, '.shipping-method-input:checked');
        const event = new Event('change', {bubbles: true});

        input.dispatchEvent(event);
    }
}
