<?php

declare(strict_types=1);

namespace Qls\ServicePoints\Service;

use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\EqualsFilter;
use Shopware\Core\System\SystemConfig\SystemConfigEntity;

class SystemConfigService
{
    private const SERVICE_POINT_SHIPPING_METHOD_ID = 'qlsServicePoints.servicePointShippingMethodId';
    private const KEY_COMPANY_ID = 'qlsServicePoints.config.companyId';

    private EntityRepository $systemConfigRepository;

    public function __construct(EntityRepository $systemConfigRepository)
    {
        $this->systemConfigRepository = $systemConfigRepository;
    }

    public function storeServicePointSystemConfig(string $shippingMethodId, Context $context): void
    {
        $data = [
            'configurationKey' => self::SERVICE_POINT_SHIPPING_METHOD_ID,
            'configurationValue' => $shippingMethodId,
        ];

        $this->systemConfigRepository->create([$data], $context);
    }

    public function getServicePointSystemConfig(Context $context): ?SystemConfigEntity
    {
        $criteria = new Criteria();
        $criteria->addFilter(new EqualsFilter('configurationKey', self::SERVICE_POINT_SHIPPING_METHOD_ID));

        return $this->systemConfigRepository->search($criteria, $context)->first();
    }

    public function getCompanyIdConfig(Context $context): ?SystemConfigEntity
    {
        $criteria = new Criteria();
        $criteria->addFilter(new EqualsFilter('configurationKey', self::KEY_COMPANY_ID));

        return $this->systemConfigRepository->search($criteria, $context)->first();
    }

    private function deleteServicePointSystemConfig(SystemConfigEntity $systemConfig, Context $context): void
    {
        $data = [
            'id' => $systemConfig->getId(),
        ];

        $this->systemConfigRepository->delete([$data], $context);
    }

    public function ensureServicePointSystemConfigIsDeleted(Context $context): void
    {
        $servicePointSystemConfig = $this->getServicePointSystemConfig($context);

        if (!$servicePointSystemConfig) {
            return;
        }

        $this->deleteServicePointSystemConfig(
            $servicePointSystemConfig,
            $context,
        );
    }
}
