<?php

declare(strict_types=1);

namespace Qls\ServicePoints\Test\Service;

use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Qls\ServicePoints\Service\OrderService;
use Qls\ServicePoints\Struct\ServicePoint;
use Shopware\Core\Checkout\Order\OrderEntity;
use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;

class OrderServiceTest extends TestCase
{
    /** @var MockObject|Context */
    private MockObject $context;

    /** @var MockObject|EntityRepository */
    private MockObject $orderRepository;

    private OrderService $orderService;

    public function setUp(): void
    {
        $this->context = $this->getMockBuilder(Context::class)->disableOriginalConstructor()->getMock();
        $this->orderRepository = $this->getMockBuilder(EntityRepository::class)->getMock();
        $this->orderService = new OrderService(
            $this->orderRepository
        );
    }

    public function testItAddsServicePointToCustomFields(): void
    {
        $order = new OrderEntity();
        $order->setId('::id::');

        $servicePoint = new ServicePoint(
            '::code::',
            '::name::',
            '::streetAndNumber::',
            '::postalCodeAndCity::',
            '::country::'
        );

        $this->orderRepository
            ->expects($this->once())
            ->method('upsert')
            ->with([[
                'id' => '::id::',
                'customFields' => [
                    'service_point_code' => '::code::',
                    'service_point_name' => '::name::',
                    'service_point_street_and_number' => '::streetAndNumber::',
                    'service_point_postal_code_and_city' => '::postalCodeAndCity::',
                    'service_point_country' => '::country::'
                ]
            ]], $this->context);

        $this->orderService->addServicePointToCustomFields($servicePoint, $order, $this->context);
    }
}
